==> rice-krad-development-tools-2.5.3.1807.0005-kualico-sources.jar: org/kuali/rice/krad/schema/SchemaGenerator.java <==
package org.kuali.rice.krad.schema;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class SchemaGenerator
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public static  org.apache.log4j.Logger getLOG() { return (org.apache.log4j.Logger)null;}
public static  java.lang.String getKRAD_SCHEMA() { return (java.lang.String)null;}
public  java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>> getNameTagMap() { return (java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>>)null;}
public  void setNameTagMap(java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>> value) { }
public  java.util.List<org.kuali.rice.krad.schema.SchemaGenerator.OtherSchemaTags> getOtherSchemaTagsList() { return (java.util.List<org.kuali.rice.krad.schema.SchemaGenerator.OtherSchemaTags>)null;}
public  void setOtherSchemaTagsList(java.util.List<org.kuali.rice.krad.schema.SchemaGenerator.OtherSchemaTags> value) { }
public  javax.xml.parsers.DocumentBuilderFactory getFactory() { return (javax.xml.parsers.DocumentBuilderFactory)null;}
public  void setFactory(javax.xml.parsers.DocumentBuilderFactory value) { }
public  javax.xml.parsers.DocumentBuilder getBuilder() { return (javax.xml.parsers.DocumentBuilder)null;}
public  void setBuilder(javax.xml.parsers.DocumentBuilder value) { }
public  java.util.List<org.w3c.dom.Element> getTypes() { return (java.util.List<org.w3c.dom.Element>)null;}
public  void setTypes(java.util.List<org.w3c.dom.Element> value) { }
public  java.util.List<org.w3c.dom.Element> getElements() { return (java.util.List<org.w3c.dom.Element>)null;}
public  void setElements(java.util.List<org.w3c.dom.Element> value) { }
public  java.util.Set<java.lang.Class<?>> getProcessedClassChoiceTypes() { return (java.util.Set<java.lang.Class<?>>)null;}
public  void setProcessedClassChoiceTypes(java.util.Set<java.lang.Class<?>> value) { }
public  java.util.Map<java.lang.String, org.w3c.dom.Element> getElementObjects() { return (java.util.Map<java.lang.String, org.w3c.dom.Element>)null;}
public  void setElementObjects(java.util.Map<java.lang.String, org.w3c.dom.Element> value) { }
public  java.util.Set<java.lang.String> getMixedTypes() { return (java.util.Set<java.lang.String>)null;}
public  void setMixedTypes(java.util.Set<java.lang.String> value) { }
public  java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo> getComponentAttributes() { return (java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo>)null;}
public  void setComponentAttributes(java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo> value) { }
public  org.w3c.dom.Element getComponentBaseElement() { return (org.w3c.dom.Element)null;}
public  void setComponentBaseElement(org.w3c.dom.Element value) { }
public  java.util.Set<java.lang.String> getSchemaFileNames() { return (java.util.Set<java.lang.String>)null;}
public  void setSchemaFileNames(java.util.Set<java.lang.String> value) { }
public  java.util.ResourceBundle getDoc() { return (java.util.ResourceBundle)null;}
public  void setDoc(java.util.ResourceBundle value) { }
public  java.lang.String[] getScanPackages() { return (java.lang.String[])null;}
public  void setScanPackages(java.lang.String... value) { }
public  java.lang.String getOutputPath() { return (java.lang.String)null;}
public  void setOutputPath(java.lang.String value) { }
public  java.util.ResourceBundle getAdditionalSchemaTagsProperties() { return (java.util.ResourceBundle)null;}
public  void setAdditionalSchemaTagsProperties(java.util.ResourceBundle value) { }
public  java.lang.String getSchemaName() { return (java.lang.String)null;}
public  void setSchemaName(java.lang.String value) { }
public  java.util.Map<java.lang.String, java.util.List<java.lang.String>> getOtherSchemaPackages() { return (java.util.Map<java.lang.String, java.util.List<java.lang.String>>)null;}
public  void setOtherSchemaPackages(java.util.Map<java.lang.String, java.util.List<java.lang.String>> value) { }
public  java.lang.Object generateSchema(java.util.ResourceBundle doc, java.lang.String[] scanPackages, java.lang.String outputPath, java.util.ResourceBundle additionalSchemaTagsProperties, java.lang.String schemaName, java.util.Map<java.lang.String, java.util.List<java.lang.String>> otherSchemaPackages) { return null;}
public  java.lang.Object buildSchemaElements() { return null;}
public  java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>> buildNameTagMap() { return (java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>>)null;}
public  org.w3c.dom.Element buildClassSchemaType(org.w3c.dom.Document document, java.lang.String type, java.lang.Class<?> clazz) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element processClassAttributes(org.w3c.dom.Document document, java.lang.Class<?> clazz, java.util.List<org.w3c.dom.Element> attributeProperties) { return (org.w3c.dom.Element)null;}
public  void createMixedType(org.w3c.dom.Document document, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo aInfo) { }
public  org.w3c.dom.Element buildByTypeChoiceElement(org.w3c.dom.Document document, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo aInfo) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element buildTypeChoiceElement(org.w3c.dom.Document document, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo aInfo, boolean forMixed) { return (org.w3c.dom.Element)null;}
public  boolean containsByTypeAttribute(java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo> targetTagAttributes, java.lang.Class<?> type) { return false;}
public  boolean containsAttribute(java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo> targetTagAttributes, java.lang.String attribute) { return false;}
public  org.w3c.dom.Element createElement(org.w3c.dom.Document document, java.lang.String name, java.lang.String type, java.lang.String minOccurs, java.lang.String maxOccurs) { return (org.w3c.dom.Element)null;}
public  void fillAndWriteSchema()throws javax.xml.transform.TransformerException, java.io.IOException { }
public  java.util.List<org.w3c.dom.Document> writeBaseTypesDocuments() { return (java.util.List<org.w3c.dom.Document>)null;}
public  java.lang.Object addGenericBaseTypes(org.w3c.dom.Document baseTypesDocument, org.w3c.dom.Element schema) { return null;}
public  java.util.List<org.w3c.dom.Document> writeTypesDocuments(java.util.List<org.w3c.dom.Document> baseTypeDocuments) { return (java.util.List<org.w3c.dom.Document>)null;}
public  org.w3c.dom.Element createAnyTypeElement(org.w3c.dom.Document document) { return (org.w3c.dom.Element)null;}
public  void writeDocument(org.w3c.dom.Document document, java.lang.String documentName)throws javax.xml.transform.TransformerException, java.io.IOException { }
public  org.w3c.dom.Element getSchemaInstance(org.w3c.dom.Document document) { return (org.w3c.dom.Element)null;}
public  java.lang.Object buildClassChoiceBaseType(org.w3c.dom.Document document, java.lang.Class<?> clazz) { return null;}
public  org.w3c.dom.Element getDocAnnotation(org.w3c.dom.Document document, java.util.ResourceBundle doc, java.lang.String className, java.lang.String property, java.lang.String propertyType) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element getListOrSetExtension(org.w3c.dom.Document document, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo aInfo, java.lang.String attrType) { return (org.w3c.dom.Element)null;}
public  boolean isKradSchema() { return false;}
public class OtherSchemaTags
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public OtherSchemaTags
(java.lang.Object schemaName, java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>> nameTagMap) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.String getSchemaName() { return (java.lang.String)null;}
public  void setSchemaName(java.lang.String schemaName) { }
public  java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>> getNameTagMap() { return (java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>>)null;}
public  void setNameTagMap(java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>> nameTagMap) { }
}
}

==> rice-krad-development-tools-2.5.3.1809.0004-kualico-sources.jar: org/kuali/rice/krad/schema/SchemaGenerator.java <==
package org.kuali.rice.krad.schema;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class SchemaGenerator
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public static  org.apache.logging.log4j.Logger getLOG() { return (org.apache.logging.log4j.Logger)null;}
public static  java.lang.String getKRAD_SCHEMA() { return (java.lang.String)null;}
public  java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>> getNameTagMap() { return (java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>>)null;}
public  void setNameTagMap(java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>> value) { }
public  java.util.List<org.kuali.rice.krad.schema.SchemaGenerator.OtherSchemaTags> getOtherSchemaTagsList() { return (java.util.List<org.kuali.rice.krad.schema.SchemaGenerator.OtherSchemaTags>)null;}
public  void setOtherSchemaTagsList(java.util.List<org.kuali.rice.krad.schema.SchemaGenerator.OtherSchemaTags> value) { }
public  javax.xml.parsers.DocumentBuilderFactory getFactory() { return (javax.xml.parsers.DocumentBuilderFactory)null;}
public  void setFactory(javax.xml.parsers.DocumentBuilderFactory value) { }
public  javax.xml.parsers.DocumentBuilder getBuilder() { return (javax.xml.parsers.DocumentBuilder)null;}
public  void setBuilder(javax.xml.parsers.DocumentBuilder value) { }
public  java.util.List<org.w3c.dom.Element> getTypes() { return (java.util.List<org.w3c.dom.Element>)null;}
public  void setTypes(java.util.List<org.w3c.dom.Element> value) { }
public  java.util.List<org.w3c.dom.Element> getElements() { return (java.util.List<org.w3c.dom.Element>)null;}
public  void setElements(java.util.List<org.w3c.dom.Element> value) { }
public  java.util.Set<java.lang.Class<?>> getProcessedClassChoiceTypes() { return (java.util.Set<java.lang.Class<?>>)null;}
public  void setProcessedClassChoiceTypes(java.util.Set<java.lang.Class<?>> value) { }
public  java.util.Map<java.lang.String, org.w3c.dom.Element> getElementObjects() { return (java.util.Map<java.lang.String, org.w3c.dom.Element>)null;}
public  void setElementObjects(java.util.Map<java.lang.String, org.w3c.dom.Element> value) { }
public  java.util.Set<java.lang.String> getMixedTypes() { return (java.util.Set<java.lang.String>)null;}
public  void setMixedTypes(java.util.Set<java.lang.String> value) { }
public  java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo> getComponentAttributes() { return (java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo>)null;}
public  void setComponentAttributes(java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo> value) { }
public  org.w3c.dom.Element getComponentBaseElement() { return (org.w3c.dom.Element)null;}
public  void setComponentBaseElement(org.w3c.dom.Element value) { }
public  java.util.Set<java.lang.String> getSchemaFileNames() { return (java.util.Set<java.lang.String>)null;}
public  void setSchemaFileNames(java.util.Set<java.lang.String> value) { }
public  java.util.ResourceBundle getDoc() { return (java.util.ResourceBundle)null;}
public  void setDoc(java.util.ResourceBundle value) { }
public  java.lang.String[] getScanPackages() { return (java.lang.String[])null;}
public  void setScanPackages(java.lang.String... value) { }
public  java.lang.String getOutputPath() { return (java.lang.String)null;}
public  void setOutputPath(java.lang.String value) { }
public  java.util.ResourceBundle getAdditionalSchemaTagsProperties() { return (java.util.ResourceBundle)null;}
public  void setAdditionalSchemaTagsProperties(java.util.ResourceBundle value) { }
public  java.lang.String getSchemaName() { return (java.lang.String)null;}
public  void setSchemaName(java.lang.String value) { }
public  java.util.Map<java.lang.String, java.util.List<java.lang.String>> getOtherSchemaPackages() { return (java.util.Map<java.lang.String, java.util.List<java.lang.String>>)null;}
public  void setOtherSchemaPackages(java.util.Map<java.lang.String, java.util.List<java.lang.String>> value) { }
public  java.lang.Object generateSchema(java.util.ResourceBundle doc, java.lang.String[] scanPackages, java.lang.String outputPath, java.util.ResourceBundle additionalSchemaTagsProperties, java.lang.String schemaName, java.util.Map<java.lang.String, java.util.List<java.lang.String>> otherSchemaPackages) { return null;}
public  java.lang.Object buildSchemaElements() { return null;}
public  java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>> buildNameTagMap() { return (java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>>)null;}
public  org.w3c.dom.Element buildClassSchemaType(org.w3c.dom.Document document, java.lang.String type, java.lang.Class<?> clazz) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element processClassAttributes(org.w3c.dom.Document document, java.lang.Class<?> clazz, java.util.List<org.w3c.dom.Element> attributeProperties) { return (org.w3c.dom.Element)null;}
public  void createMixedType(org.w3c.dom.Document document, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo aInfo) { }
public  org.w3c.dom.Element buildByTypeChoiceElement(org.w3c.dom.Document document, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo aInfo) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element buildTypeChoiceElement(org.w3c.dom.Document document, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo aInfo, boolean forMixed) { return (org.w3c.dom.Element)null;}
public  boolean containsByTypeAttribute(java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo> targetTagAttributes, java.lang.Class<?> type) { return false;}
public  boolean containsAttribute(java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo> targetTagAttributes, java.lang.String attribute) { return false;}
public  org.w3c.dom.Element createElement(org.w3c.dom.Document document, java.lang.String name, java.lang.String type, java.lang.String minOccurs, java.lang.String maxOccurs) { return (org.w3c.dom.Element)null;}
public  void fillAndWriteSchema()throws javax.xml.transform.TransformerException, java.io.IOException { }
public  java.util.List<org.w3c.dom.Document> writeBaseTypesDocuments() { return (java.util.List<org.w3c.dom.Document>)null;}
public  java.lang.Object addGenericBaseTypes(org.w3c.dom.Document baseTypesDocument, org.w3c.dom.Element schema) { return null;}
public  java.util.List<org.w3c.dom.Document> writeTypesDocuments(java.util.List<org.w3c.dom.Document> baseTypeDocuments) { return (java.util.List<org.w3c.dom.Document>)null;}
public  org.w3c.dom.Element createAnyTypeElement(org.w3c.dom.Document document) { return (org.w3c.dom.Element)null;}
public  void writeDocument(org.w3c.dom.Document document, java.lang.String documentName)throws javax.xml.transform.TransformerException, java.io.IOException { }
public  org.w3c.dom.Element getSchemaInstance(org.w3c.dom.Document document) { return (org.w3c.dom.Element)null;}
public  java.lang.Object buildClassChoiceBaseType(org.w3c.dom.Document document, java.lang.Class<?> clazz) { return null;}
public  org.w3c.dom.Element getDocAnnotation(org.w3c.dom.Document document, java.util.ResourceBundle doc, java.lang.String className, java.lang.String property, java.lang.String propertyType) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element getListOrSetExtension(org.w3c.dom.Document document, org.kuali.rice.krad.datadictionary.parse.BeanTagAttributeInfo aInfo, java.lang.String attrType) { return (org.w3c.dom.Element)null;}
public  boolean isKradSchema() { return false;}
public class OtherSchemaTags
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public OtherSchemaTags
(java.lang.Object schemaName, java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>> nameTagMap) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.String getSchemaName() { return (java.lang.String)null;}
public  void setSchemaName(java.lang.String schemaName) { }
public  java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>> getNameTagMap() { return (java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>>)null;}
public  void setNameTagMap(java.util.Map<java.lang.String, java.util.Map<java.lang.String, org.kuali.rice.krad.datadictionary.parse.BeanTagInfo>> nameTagMap) { }
}
}
